@@ -20,7 +20,24 @@ from threading import Thread
 import pluggy
 import py
 import six
-import toml
+
+if sys.version_info >= (3, 11):
+    import tomllib as toml_loader
+
+    toml_mode = "rb"
+    toml_encoding = None
+elif sys.version_info >= (3, 7):
+    import tomli as toml_loader
+
+    toml_mode = "rb"
+    toml_encoding = None
+else:
+    import toml as toml_loader
+
+    toml_mode = "r"
+    toml_encoding = "UTF-8"
+
+
 from packaging import requirements
 from packaging.utils import canonicalize_name
 from packaging.version import Version
@@ -44,9 +61,9 @@ from .parallel import ENV_VAR_KEY_PUBLIC as PARALLEL_ENV_VAR_KEY_PUBLIC
 from .parallel import add_parallel_config, add_parallel_flags
 from .reporter import add_verbosity_commands
 
-try:
+if sys.version_info >= (3, 3):
     from shlex import quote as shlex_quote
-except ImportError:
+else:
     from pipes import quote as shlex_quote
 
 
@@ -304,9 +321,9 @@ def parseconfig(args, plugins=()):
 
 
 def get_py_project_toml(path):
-    with io.open(str(path), encoding="UTF-8") as file_handler:
-        config_data = toml.load(file_handler)
-        return config_data
+    with io.open(str(path), mode=toml_mode, encoding=toml_encoding) as file_handler:
+        config_data = toml_loader.load(file_handler)
+    return config_data
 
 
 def propose_configs(cli_config_file):
@@ -796,6 +813,7 @@ def tox_addoption(parser):
         # but this leads to very long paths when run with jenkins
         # so we just pass it on by default for now.
         if tox.INFO.IS_WIN:
+            passenv.add("APPDATA")  # needed to find user site-packages location
             passenv.add("SYSTEMDRIVE")  # needed for pip6
             passenv.add("SYSTEMROOT")  # needed for python's crypto module
             passenv.add("PATHEXT")  # needed for discovering executables
@@ -1483,7 +1501,7 @@ class ParseIni(object):
                 reader.addsubstitutions(**{env_attr.name: res})
         return tc
 
-    def _getallenvs(self, reader, extra_env_list=None):
+    def _getallenvs(self, reader, config, extra_env_list=None):
         extra_env_list = extra_env_list or []
         env_str = reader.getstring("envlist", replace=False)
         env_list = _split_env(env_str)
@@ -1492,9 +1510,12 @@ class ParseIni(object):
                 env_list.append(env)
 
         all_envs = OrderedDict((i, None) for i in env_list)
+        package_env = config.isolated_build_env if config.isolated_build is True else None
         for section in self._cfg:
             if section.name.startswith(testenvprefix):
-                all_envs[section.name[len(testenvprefix) :]] = None
+                section_env = section.name[len(testenvprefix) :]
+                if section_env != package_env:
+                    all_envs[section_env] = None
         if not all_envs:
             all_envs["python"] = None
         return list(all_envs.keys())
@@ -1510,7 +1531,7 @@ class ParseIni(object):
             (from_option and "ALL" in from_option)
             or (not from_option and from_environ and "ALL" in from_environ.split(","))
         ) and PARALLEL_ENV_VAR_KEY_PRIVATE not in os.environ:
-            all_envs = self._getallenvs(reader)
+            all_envs = self._getallenvs(reader, config)
         else:
             candidates = (
                 (os.environ.get(PARALLEL_ENV_VAR_KEY_PRIVATE), True),
@@ -1521,7 +1542,7 @@ class ParseIni(object):
             )
             env_str, envlist_explicit = next(((i, e) for i, e in candidates if i), ([], False))
             env_list = _split_env(env_str)
-            all_envs = self._getallenvs(reader, env_list)
+            all_envs = self._getallenvs(reader, config, env_list)
 
         if not env_list:
             env_list = all_envs
@@ -1532,9 +1553,6 @@ class ParseIni(object):
             raise tox.exception.ConfigError(msg)
 
         package_env = config.isolated_build_env
-        if config.isolated_build is True and package_env in all_envs:
-            all_envs.remove(package_env)
-
         if config.isolated_build is True and package_env in env_list:
             msg = "isolated_build_env {} cannot be part of envlist".format(package_env)
             raise tox.exception.ConfigError(msg)
