@@ -29,7 +29,7 @@ def _ensure_module_in_paths(module, paths):
 dist_folder = sys.argv[1]
 backend_spec = sys.argv[2]
 backend_obj = sys.argv[3] if len(sys.argv) >= 4 else None
-backend_paths = sys.argv[4].split(os.path.pathsep) if sys.argv[4] else []
+backend_paths = sys.argv[4].split(os.path.pathsep) if (len(sys.argv) >= 5 and sys.argv[4]) else []
 
 sys.path[:0] = backend_paths
 
@@ -38,5 +38,5 @@ _ensure_module_in_paths(backend, backend_paths)
 if backend_obj:
     backend = getattr(backend, backend_obj)
 
-basename = backend.build_sdist(dist_folder, {"--global-option": ["--formats=gztar"]})
+basename = backend.build_sdist(dist_folder, {"--build-option": ["--formats=gztar"]})
 print(basename)
