@@ -3,6 +3,11 @@ import threading
 from contextlib import contextmanager
 from tempfile import TemporaryFile
 
+if sys.version_info >= (3, 8):
+    from importlib import metadata as importlib_metadata  # noqa
+else:
+    import importlib_metadata  # noqa
+
 
 def is_main_thread():
     """returns true if we are within the main thread"""
@@ -19,7 +24,7 @@ def is_main_thread():
 def suppress_output():
     """suppress both stdout and stderr outputs"""
     if sys.version_info >= (3, 5):
-        from contextlib import redirect_stdout, redirect_stderr
+        from contextlib import redirect_stderr, redirect_stdout
     else:
 
         class _RedirectStream(object):
